@@ -2,7 +2,6 @@
 #' maxWithoutNA
 #' Function that returns NA if all elements are NA, and the max value not NA, if not.
 #' @param x vector parameter
-
 maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm=TRUE), NA)
 
 
@@ -34,8 +33,6 @@ maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm=TRUE), NA)
 #' @import utils
 #' @importFrom R6 R6Class
 #' @export
-#'
-
 ScraperLedger.class <- R6::R6Class("ScraperLedger",
  public = list(
    states = NULL,
@@ -180,7 +177,7 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
        self$dirty <- FALSE
      }
    },
-   getAvailablePolyhedra = function(sources = names(.available.sources),
+   getAvailablePolyhedra = function(sources = names(getPackageEnvir(".available.sources")),
                                     search.string = "",
                                     ret.fields = c("source","name","vertices","faces","status"),
                                     ignore.case = TRUE){
